@@ -270,6 +270,9 @@ class Action(App):
             "navigator_mode": "interactive",
             "pass_environment_variable": self._args.pass_environment_variable,
             "set_environment_variable": set_environment_variable,
+            "private_data_dir": self._args.ansible_runner_artifact_dir,
+            "rotate_artifacts": self._args.ansible_runner_rotate_artifacts_count,
+            "timeout": self._args.ansible_runner_timeout,
         }
 
         if isinstance(self._args.playbook, str):
@@ -282,7 +285,7 @@ class Action(App):
                 {"container_volume_mounts": self._args.execution_environment_volume_mounts}
             )
 
-        kwargs.update({"cwd": playbook_dir})
+        kwargs.update({"host_cwd": playbook_dir})
 
         self._adjacent_collection_dir = os.path.join(playbook_dir, "collections")
         share_directory = self._args.internals.share_directory
@@ -301,7 +304,7 @@ class Action(App):
             self._logger.debug("running collections command with execution environment enabled")
             python_exec_path = "python3"
 
-            container_volume_mounts = [f"{share_directory}/utils:{share_directory}/utils:z"]
+            container_volume_mounts = [f"{share_directory}/utils:{share_directory}/utils"]
             if os.path.exists(self._adjacent_collection_dir):
                 container_volume_mounts.append(
                     f"{self._adjacent_collection_dir}:{self._adjacent_collection_dir}:z"
@@ -320,7 +323,7 @@ class Action(App):
             f"Invoke runner with executable_cmd: {python_exec_path}" + f" and kwargs: {kwargs}"
         )
         _runner = CommandRunner(executable_cmd=python_exec_path, **kwargs)
-        output, error = _runner.run()
+        output, error, _ = _runner.run()
 
         if error:
             msg = f"Error while running catalog collection script: {error}"
