@@ -1,12 +1,12 @@
 """ ansible_runner API's interface
 """
-import shutil
-import sys
 import logging
 import os
+import shutil
+import tempfile
+import sys
 
 from queue import Queue
-from tempfile import gettempdir
 from typing import Any
 from typing import Dict
 from typing import List
@@ -41,6 +41,8 @@ class BaseRunner:
         set_environment_variable: Optional[Dict] = None,
         pass_environment_variable: Optional[List] = None,
         host_cwd: Optional[str] = None,
+        rotate_artifacts: Optional[int] = None,
+        timeout: Optional[int] = None,
     ) -> None:
         """BaseRunner class handle common argument for ansible-runner interface class
 
@@ -75,12 +77,16 @@ class BaseRunner:
                                    path will be volume mounted within the execution enviornment
             set_environment_variable([dict], optional): Dict of user requested envvars to set
             pass_environment_variable([list], optional): List of user requested envvars to pass
+            rotate_artifacts ([int], optional): Keep at most n artifact directories
+            timeout ([int], optional): The timeout value in seconds that will be passed to either
+                                       ``pexpect`` of ``subprocess`` invocation
+                                       (based on ``runner_mode`` selected) while executing command.
+                                       It the timeout is triggered it will force cancel the
+                                       execution.
         """
-        if private_data_dir:
-            self._private_data_dir = private_data_dir
-        else:
-            self._private_data_dir = os.path.join(gettempdir(), "ansible-navigator")
+        self._logger = logging.getLogger(__name__)
 
+        self._set_private_data_directory(private_data_dir)
         self._ce = container_engine
         self._ee = execution_environment
         self._eei = execution_environment_image
@@ -92,11 +98,12 @@ class BaseRunner:
             pass_environment_variable if isinstance(pass_environment_variable, list) else []
         )
         self._host_cwd = host_cwd
+        self._rotate_artifacts = rotate_artifacts if isinstance(rotate_artifacts, int) else None
+        self._timeout = timeout if isinstance(timeout, int) else None
         self.ansible_runner_instance: Runner
         self.cancelled: bool = False
         self.finished: bool = False
         self.status: Optional[str] = None
-        self._logger = logging.getLogger(__name__)
         self._runner_args: Dict = {}
         self._runner_artifact_dir: Optional[str] = None
         if self._ee:
@@ -118,12 +125,18 @@ class BaseRunner:
                 "cancel_callback": self.runner_cancelled_callback,
                 "finished_callback": self.runner_finished_callback,
                 "artifacts_handler": self.runner_artifacts_handler,
+                "timeout": self._timeout,
             }
         )
+        if self._rotate_artifacts is not None:
+            self._runner_args.update({"rotate_artifacts": self._rotate_artifacts})
+
         self._add_env_vars_to_args()
 
         if self._host_cwd:
-            self._runner_args.update({"host_cwd": self._host_cwd})
+            # ensure the cwd ends with a trailing slash
+            host_cwd = os.path.join(self._host_cwd, "")
+            self._runner_args.update({"host_cwd": host_cwd})
 
         if self._navigator_mode == "stdout":
             self._runner_args.update(
@@ -132,14 +145,43 @@ class BaseRunner:
 
     def __del__(self):
         """
-        class destructor, handle runner artifact file deletion
+        class destructor, handle runner artifact file deletion is rotate_artifacts
+        vlaue is not set
         """
-        if self._runner_artifact_dir and os.path.exists(self._runner_artifact_dir):
+        if (
+            self._rotate_artifacts is not None
+            and self._runner_artifact_dir
+            and os.path.exists(self._runner_artifact_dir)
+        ):
+
             self._logger.debug(
                 "delete ansible-runner artifact directory at path %s", self._runner_artifact_dir
             )
             shutil.rmtree(self._runner_artifact_dir, ignore_errors=True)
 
+    @staticmethod
+    def _generate_tmp_directory():
+        """generate a tmp directory for artifacts"""
+        return tempfile.mkdtemp(prefix="ansible-navigator_")
+
+    def _set_private_data_directory(self, provided: Union[str, None]) -> None:
+        """Set the private data directory to the provided, the username, or a uuid"""
+
+        if isinstance(provided, str):
+            if os.access(provided, os.W_OK | os.R_OK | os.X_OK):
+                private_data_directory = provided
+                source = "user provided"
+            else:
+                self._logger.debug("Provided private data dir `%s` was not user writable")
+                private_data_directory = self._generate_tmp_directory()
+                source = "user provided, but changed to tmp location due to permissions"
+        else:
+            private_data_directory = self._generate_tmp_directory()
+            source = "not user provided, used tmp location"
+
+        self._private_data_dir = private_data_directory
+        self._logger.debug("private data dir %s: %s", source, self._private_data_dir)
+
     def runner_artifacts_handler(self, artifact_dir):
         """
         ansible-runner callback to handle artifacts after each runner innvocation
@@ -262,12 +304,12 @@ class CommandRunner(CommandBaseRunner):
     # pylint: disable=too-many-instance-attributes
     """a runner wrapper"""
 
-    def run(self) -> Tuple[str, str]:
+    def run(self) -> Tuple[str, str, int]:
         """run"""
 
         self.generate_run_command_args()
-        out, err = run_command(**self._runner_args)
-        return out, err
+        out, err, ret_code = run_command(**self._runner_args)
+        return out, err, ret_code
 
 
 class AnsibleCfgRunner(BaseRunner):
